@@ -15,7 +15,7 @@
 #define ATKMM_MINOR_VERSION 28
 
 /* Micro version number of atkmm. */
-#define ATKMM_MICRO_VERSION 1
+#define ATKMM_MICRO_VERSION 2
 
 /* Define when building atkmm as a static library. */
 /* #undef ATKMM_STATIC_LIB */
@@ -28,8 +28,10 @@
 #ifdef ATKMM_DLL
 # ifdef ATKMM_BUILD
 #  define ATKMM_API __declspec(dllexport)
-# else
+# elif !defined (__GNUC__)
 #  define ATKMM_API __declspec(dllimport)
+# else /* don't dllimport classes/methods on GCC/MinGW */
+#  define ATKMM_API
 # endif
 #else
 # define ATKMM_API
